%FilterWheel_Usage: PROPERTIES, METHODS, USAGE
%Before use open serial port.
[s,error] = EZStepperOpenSerial('COM4');

%After use close serial port
[error] = EZStepperCloseSerial(s);

%Create FilterWheel object: 
%Two parameters, PortObj and ControllerName are required, other parameters are optional.
%PortObj is the serial port object.
%ControllerName is the controller number on this serial line.
%Values shown are typical defaults. 
%Default or supplied values are loaded into controller at object creation.
fw=FilterWheel('PortObj', s, 'ControllerName', 1, 'FilterPositions', 12, 'MotorSteps', 200, ...
    'HoldCurrent', 10, 'RunCurrent', 50, 'StepDivide', 16, 'SlewVelocity', 10000, ...
    'InitVelocity', 100, 'Ramp', 12, 'OffsetFromHome', -2, 'Log', 0);

%Parameters and (defaults):

FilterPositions = 12; %number of filter positions in the wheel
MotorSteps = 200; %physical steps in the motor; typically 200
HoldCurrent = 10; %current when not moving; in % of full (2A for EZHR17); typically 10%
RunCurrent = 60; %current when moving; in % of full (2A for EZHR17); typically 60%
StepDivide = 16; %number of microsteps per step; typically 16
SlewVelocity = 10000; %slew (max) velocity in microsteps/sec
InitVelocity = 100; %initial velocity in microsteps/sec 
Ramp = 12; %acceleration (deceleration) in microsteps/sec^2 
OffsetFromHome = -2; %offset from home to the position of the first filter in microsteps
Log = 0; %0 - do not accumulate log; 1 - accumulate log

%Get parameters - values are read from the object data structure. 
%(Ramp is used as an example)
v = get(fw,'Ramp'); 
%Set parameters - values are written to the object data structure and loaded into controller.
set(fw,'Ramp',v);

%Methods
err = WheelHome(fw); %Start moving home at given speed; do not wait for completion.
%During homing motor moves in the direction of decreasing position.

err = WheelMove(fw, filt); %Move the filter wheel from the current position to the position

err = WheelNext(fw); %Move the filter wheel to the next filter position

err = WheelPrev(fw); %Move the filter wheel to the previous filter position

err = WheelWait(fw); %Wait for completion of motion;

[filt, err, mpos] = WheelPos(fw); %Returns current filter, error, and position in microsteps.

log = EZStepperLog(); %Returns log of all executed commands while LogRecord was equal to 1.

EZStepperClearLog; %Clear accumulated log.

%GUI FUNCTIONS
FilterWheel_UI - %Starts FilterWheel GUI. User must use menus to open COM port and create FilterWheel object.
%All parameters are changeable by the user. At start GUI figure reads parameter file FilterWheel.mat from the current 
%directory (if present). Parameter file is (re)written after object creation.
FilterWheel_UI(<parameter list>); %e.g. any or all of parameters:
FilterWheel_UI('PortObj', s, 'ControllerName', 1, 'FilterPositions', 12, 'MotorSteps', 200, ...
    'HoldCurrent', 10, 'RunCurrent', 60, 'StepDivide', 16, 'SlewVelocity', 10000, ...
    'InitVelocity', 100, 'Ramp', 12, 'OffsetFromHome', -2, 'Log', 0);
%Parameters that are in the list can not be changed by the user from the GUI. 
%Parameters that are not in the list can be changed by the user from the GUI.
%Parameters from the command line override parameters read from the file.
%If Serial Port Object was created before invoking the GUI and passed to
%it, the port does not need to (and can not) be opened. However, the user still
%must create the FilterWheel object in the menu: Initialize/Create FD Object.

%THIS EXAMPLE CREATES TWO FIGURES CONTROLLING TWO FOCUS DRIVES ON THE SAME SERIAL PORT
[s,err01] = EZStepperOpenSerial('COM1');
FilterWheel_UI('PortObj', s, 'ControllerName', 2);
FilterWheel_UI('PortObj', s, 'ControllerName', 1);

% Relevant functions:

%               EZStepperOpenSerial  EZStepperCloseSerial 
%               EZStepperLog         EZStepperClearLog  
%               FilterWheel_Test*    FilterWheel_UI (.m and .fig)
%               FilterWheel_Usage    FilterWheel
